package com.u1aryz.samples.multi_screen;

import android.content.Intent;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.view.View;

import com.u1aryz.samples.multi_screen.MasterFragment.OnMasterItemClickListener;

/**
 * メインのアクティビティ
 * 
 * @author u1aryz
 * 
 */
public class MainActivity extends FragmentActivity implements
		OnMasterItemClickListener {

	MasterFragment mMasterFragment;
	DetailFragment mDetailFragment;

	/** 2ペインモードフラグ */
	boolean mIsTwoPane;

	/** 選択されているポジション */
	int mCurrentPosition = 0;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main_layout);

		mMasterFragment = (MasterFragment) getSupportFragmentManager()
				.findFragmentById(R.id.master);

		mDetailFragment = (DetailFragment) getSupportFragmentManager()
				.findFragmentById(R.id.detail);

		// レイアウトにDetailフラグメントがあるかどうかで2ペインモードかどうかを判定
		View v = findViewById(R.id.detail);
		mIsTwoPane = v != null && v.getVisibility() == View.VISIBLE;

		mMasterFragment.setOnMasterItemClickListener(this);

		if (savedInstanceState != null) {
			mCurrentPosition = savedInstanceState.getInt("currentPosition");
		}

		// 2ペインモードの場合、詳細を表示
		if (mIsTwoPane) {
			mDetailFragment.loadDetail(mCurrentPosition);
		}
	}

	/**
	 * リストが選択されると呼ばれる
	 */
	@Override
	public void onMasterItemClick(int position) {
		// 選択されたポジションを保持
		mCurrentPosition = position;

		if (mIsTwoPane) {
			// フラグメントの内容を切り替える
			mDetailFragment.loadDetail(position);

		} else {
			// 詳細画面表示用のActivityを起動する
			Intent intent = new Intent(this, DetailActivity.class);
			intent.putExtra("currentPosition", position);
			startActivity(intent);
		}
	}

	@Override
	protected void onSaveInstanceState(Bundle outState) {
		super.onSaveInstanceState(outState);
		// 選択されたポジションを保存
		outState.putInt("currentPosition", mCurrentPosition);
	}
}
