package com.u1aryz.samples.multi_screen;

import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentTransaction;

import com.u1aryz.samples.multi_screen.MasterFragment.OnMasterItemClickListener;

/**
 * メインのアクティビティ
 * 
 * @author u1aryz
 * 
 */
public class MainActivity extends FragmentActivity implements
		OnMasterItemClickListener {

	DetailFragment mDetailFragment;

	/** 2ペインモードフラグ */
	boolean mIsTwoPane;

	/** 選択されているポジション */
	int mCurrentPosition = 0;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main_layout);

		if (savedInstanceState != null) {
			mCurrentPosition = savedInstanceState.getInt("currentPosition");
		}

		// インフレートしたレイアウトにid:fragment_containerがあるかどうかで2ペインモードかどうか判定する
		mIsTwoPane = findViewById(R.id.fragment_container) == null;

		if (!mIsTwoPane) {

			if (savedInstanceState != null) {
				return;
			}

			MasterFragment f = new MasterFragment();
			getSupportFragmentManager().beginTransaction()
					.add(R.id.fragment_container, f).commit();
		} else {
			mDetailFragment = (DetailFragment) getSupportFragmentManager()
					.findFragmentById(R.id.detail);
			mDetailFragment.loadDetail(mCurrentPosition);
		}
	}

	/**
	 * リストが選択されると呼ばれる
	 */
	@Override
	public void onMasterItemClick(int position) {
		// 選択されたポジションを保持
		mCurrentPosition = position;

		if (mIsTwoPane) {
			// フラグメントの内容を切り替える
			mDetailFragment.loadDetail(position);

		} else {
			// フラグメントを生成して現在表示しているフラグメントとリプレイスする
			DetailFragment f = new DetailFragment();
			Bundle args = new Bundle();
			args.putInt("currentPosition", mCurrentPosition);
			f.setArguments(args);
			FragmentTransaction transaction = getSupportFragmentManager()
					.beginTransaction();
			transaction.replace(R.id.fragment_container, f);
			transaction.addToBackStack(null);
			transaction.commit();
		}
	}

	@Override
	protected void onSaveInstanceState(Bundle outState) {
		super.onSaveInstanceState(outState);
		// 選択されたポジションを保存
		outState.putInt("currentPosition", mCurrentPosition);
	}
}
